Power7

## The absurdity of the Power 750 server

The Power 750 was an absurd purchase - 100% worth it - but still absurd. It came with 768GB of RAM (to be fair I didn't know this at the time) which means it wasn't a bad $100 purchase, but at the same time it'll only run big endian operating systems on it, which is hard to find now - plus it is incredibly loud

It has been moved into a UCC (UWA's University Computer Club) rack, and is in theory on loan to them - but we are still trying to get it to boot (if anyone has a HMC please HMU), although the longer term goal is to run *something* (none of us know what yet lol) on it - although it may be too loud even by UCC standards